import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
//displaying the title
const render = data => {
  const title = 'Women in Congress';
  //x-paxix label
  const xValue = d => d.Years;
  const xAxisLabel = 'Years';
  //y-axis label
  const yValue = d => d.Women_total;
  const circleRadius = 6;
  const yAxisLabel = 'Women_total';
  //styles of chart
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  //Creating X scale with years value
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  //Creating Y scale with number of women in congress
  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxisTickFormat = number =>
    format('.1s')(number)
      .replace('G', 'B');
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text') //appending yaxis to svg
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text('Number of Women');
  
  const xAxisG = g.append('g').call(xAxis) //appending x axis to svg
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  //area graph generator
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScale(yValue(d)))
    
  //appending the area generator to svg
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', areaGenerator(data));
  
  svg.append('text') //appending the title to svg
      .attr('class', 'title')
      .attr('x', width / 2)
      .attr('y', 45)
      .text(title);
};
// gist of dataset linked
csv('https://gist.githubusercontent.com/Rinoj-Gautam/c4a1829b3ca4eb1bcc08563853486d2c/raw/50fa319aeab4871337dbe014e03272198a51cdd6/womenincongress.csv')
  .then(data => {
    data.forEach(d => {
      d.Women_total = +d.Women_total;
      d.Year = d.Year;
    });
  //selecting last few rows of the data only
    if (data) {
      render(data.slice(44, 52));
    }
  });